Array Creation Routines
=======================

.. https://docs.scipy.org/doc/numpy/reference/routines.array-creation.html

Basic creation routines
-----------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.empty
   cupy.empty_like
   cupy.eye
   cupy.identity
   cupy.ones
   cupy.ones_like
   cupy.zeros
   cupy.zeros_like
   cupy.full
   cupy.full_like


Creation from other data
------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.array
   cupy.asarray
   cupy.asanyarray
   cupy.ascontiguousarray
   cupy.copy
   cupy.fromfile


Numerical ranges
----------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.arange
   cupy.linspace
   cupy.logspace
   cupy.meshgrid
   cupy.mgrid
   cupy.ogrid


Matrix creation
---------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.diag
   cupy.diagflat
   cupy.tri
   cupy.tril
   cupy.triu
